@@ -30,7 +30,7 @@ test_that("Dalponte's methods works", {
   # Test if a seed is not in the chm
   old = ttopsdf[1,1]
   ttopsdf[1,1] <- 0
-  expect_error(lastrees_dalponte(las, chm, ttopsdf, extra = T), "outside")
+  expect_warning(lastrees_dalponte(las, chm, ttopsdf, extra = T), "outside")
 
   # Test if seed IDs are propagated
   ttopsdf[1,1] <- old
